package com.zd.exam.mapper;

import java.util.List;

import com.zd.exam.domain.ElUserExam;

/**
 * 考试记录Mapper接口
 *
 * @author zd
 * @date 2021-09-01
 */
public interface ElUserExamMapper {
    /**
     * 查询考试记录
     *
     * @param id 考试记录主键
     * @return 考试记录
     */
    public ElUserExam selectElUserExamById(Long id);

    /**
     * 查询考试记录列表
     *
     * @param elUserExam 考试记录
     * @return 考试记录集合
     */
    public List<ElUserExam> selectElUserExamList(ElUserExam elUserExam);

    /**
     * 新增考试记录
     *
     * @param elUserExam 考试记录
     * @return 结果
     */
    public int insertElUserExam(ElUserExam elUserExam);

    /**
     * 修改考试记录
     *
     * @param elUserExam 考试记录
     * @return 结果
     */
    public int updateElUserExam(ElUserExam elUserExam);

    /**
     * 删除考试记录
     *
     * @param id 考试记录主键
     * @return 结果
     */
    public int deleteElUserExamById(Long id);

    /**
     * 批量删除考试记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElUserExamByIds(Long[] ids);
}
